/*
 * Copyright (c) 2006-2013 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.addons.ui_fx.userlist;

import com.dmdirc.parser.interfaces.ClientInfo;
import java.util.Collections;
import java.util.List;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.scene.control.ListView;
import javafx.scene.control.SelectionMode;

/**
 * User list controller.
 */
public class UserListController {
    /**
     * Selected user list.
     */
    private ObservableList<Integer> selectedUsers;

    /**
     * User list we're controlling.
     */
    @FXML
    private ListView<ClientInfo> userList;
    /**
     * List of users.
     */
    private ObservableList<ClientInfo> users;

    /**
     * Adds a user to the list.
     * <p>
     * @param user User to add
     */
    public void addUser(ClientInfo user) {
        users.add(user);
    }

    /**
     * Returns the list of selected users.
     * <p>
     * @return Copy of the selected user list
     */
    public List<Integer> getSelectedUsers() {
        return Collections.unmodifiableList(selectedUsers);
    }

    /**
     * Returns the list of users.
     *
     * @return Copy of the user list
     */
    public List<ClientInfo> getUsers() {
        return Collections.unmodifiableList(users);
    }

    /**
     * Sets the list of users.
     *
     * @param users New user list
     */
    public void setUsers(final List<ClientInfo> users) {
        this.users.setAll(users);
    }

    /**
     * Initialises the controller.
     */
    public void initialize() {
        userList.getSelectionModel().setSelectionMode(SelectionMode.MULTIPLE);
        selectedUsers = userList.getSelectionModel().getSelectedIndices();
        users = userList.getItems();
    }

    /**
     * Removes a user from the list.
     *
     * @param user User to remove
     */
    public void removeUser(ClientInfo user) {
        users.remove(user);
    }

    /**
     * Sets the UI user list. Intended primarily for testing.
     */
    void setUserList(final ListView<ClientInfo> listView) {
        userList = listView;
    }
}
